<?php
/**
 * The public-facing functionality of the plugin.
 *
 * @link       firehawkcrm.com
 * @since      1.0.0
 *
 * @package    Fcrm_Service
 * @subpackage Fcrm_Service/public
 * @author     Grant Bevan <grant@firehawk.digital>
 */

class Fcrm_Service_Public
{

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $plugin_name       The name of the plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct($plugin_name, $version)
    {
        $this->plugin_name = $plugin_name;
        $this->version = $version;
    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_styles()
    {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Fcrm_Service_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Fcrm_Service_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        wp_enqueue_style($this->plugin_name . '-glidejs-core', plugin_dir_url(__FILE__) . 'js/glidejs/css/glide.core.min.css', array(), $this->version, 'all');
        wp_enqueue_style($this->plugin_name . '-glidejs-theme', plugin_dir_url(__FILE__) . 'js/glidejs/css/glide.theme.min.css', array(), $this->version, 'all');

        wp_enqueue_style($this->plugin_name . '-jquery-modal', plugin_dir_url(__FILE__) . 'css/jquery.modal.min.css', array(), $this->version, 'all');

        wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/fcrm-service-public.css', array(), $this->version, 'all');
        wp_enqueue_style('fontawesome', 'https://use.fontawesome.com/releases/v5.12.1/css/all.css', array(), $this->version, 'all');
    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts()
    {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Fcrm_Service_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Fcrm_Service_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */


        wp_enqueue_script('popperjs', 'https://unpkg.com/@popperjs/core@2', array( 'jquery' ), $this->version, false);
        wp_enqueue_script('tippyjs', 'https://unpkg.com/tippy.js@6', array( 'jquery' ), $this->version, false);

        wp_enqueue_script($this->plugin_name . '-clipboard', plugin_dir_url(__FILE__) . 'js/clipboard.min.js', array(), $this->version, false);
        wp_enqueue_script($this->plugin_name . '-glidejs', plugin_dir_url(__FILE__) . 'js/glidejs/glide.min.js', array( 'jquery' ), $this->version, false);
        wp_enqueue_script($this->plugin_name . '-jquery-modal', plugin_dir_url(__FILE__) . 'js/jquery.modal.min.js', array( 'jquery' ), $this->version, false);

        wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/sharer.min.js', array( 'jquery' ), $this->version, false);

        wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/fcrm-service-public.js', array( 'jquery' ), $this->version, false);
    }

    private function formatName($client, $format)
    {
      $names = array();
      if ($format == "display") {
        if (isset($client->firstName)) array_push($names, $client->firstName);
        if (isset($client->otherNames)) array_push($names, $client->otherNames);
        if (isset($client->lastName)) array_push($names, $client->lastName);
        return join(" ", $names);
      } else {
        if (isset($client->lastName)) array_push($names, $client->lastName.',');
        if (isset($client->firstName)) array_push($names, $client->firstName);
        if (isset($client->otherNames)) array_push($names, $client->otherNames);
        if (isset($client->knownAs)) array_push($names, "'".$client->knownAs."'");
        return join(" ", $names);
      }
    }

    /**
        * Public function to return information about the currently active filters
        *
        * @since 1.0.0
        */
    public function shortcode_crm_service_display($attributes)
    {
        if (!isset($attributes['client_id'])) {
            return null;
        }
        $clientId = $attributes['client_id'];
        $detailPage = $attributes['detail-page'];

        ob_start();
        require_once (plugin_dir_path(dirname(__FILE__)) . 'public/partials/fcrm-service-public-info-display.php');
        $content = ob_get_clean();
        return $content;
    }

    /**
     * Public function to return list display of services
     *
     * @since 1.0.0
     */
    public function shortcode_crm_service_list_display($attributes)
    {
        if (isset($attributes["limit"]) && isset($attributes["limit"]) > 50) {
            $attributes["limit"] = 50;
        }

        $detailPage = $attributes['detail-page'];
        $clients = Fcrm_Service_Api::get_clients($attributes);

        ob_start();
        require_once (plugin_dir_path(dirname(__FILE__)) . 'public/partials/fcrm-service-public-list-display.php');
        $content = ob_get_clean();
        return $content;
    }

    /**
     * Public function to return grid display of services
     *
     * @since 1.0.0
     */
    public function shortcode_crm_service_grid_display($attributes)
    {
        if (isset($attributes["limit"]) && isset($attributes["limit"]) > 50) {
            $attributes["limit"] = 50;
        }
        $detailPage = $attributes['detail-page'];

        $clients = Fcrm_Service_Api::get_clients($attributes);
        $clients = isset($clients) ? $clients : [];
        $date_check = strtotime("now");
        $difference       = null;
        $difference_index = 0;

        for ($i = 0; $i < count($clients); $i++) {
            $client = $clients[$i];
            $client->fullName = $this::formatName($client, $attributes["name-format"]);

            if (!empty($client->serviceDateTime)) {
                $d = strtotime($client->serviceDateTime);

                $diff = abs($d - $date_check);

                if ($difference == null || $diff < $difference) {
                    $difference = $diff;
                    $difference_index = $i;
                }
            }
        }

        usort($clients, function($a, $b) {
            return strcmp($a->serviceDateTime, $b->serviceDateTime);
        });

        ob_start();
        require_once (plugin_dir_path(dirname(__FILE__)) . 'public/partials/fcrm-service-public-grid-display.php');
        $content = ob_get_clean();
        return $content;
    }

    /**
     * Public function to return details of a service
     *
     * @since 1.0.0
     */
    public function shortcode_crm_service_details_display($atts)
    {
        global $client;

        $attributes = shortcode_atts(array('name-format' => null, 'detail-page' => null), $atts);
        $detailPage = $attributes['detail-page'];
        $id = $_GET["id"];

        if (!isset($client)) {
          $client = Fcrm_Service_Api::get_client($id);
        }

        if (isset($client)) {
          $client->fullName = $this::formatName($client, $attributes["name-format"]);
        }
        ob_start();
        require_once (plugin_dir_path(dirname(__FILE__)) . 'public/partials/fcrm-service-public-detail-display.php');
        $content = ob_get_clean();
        return $content;
    }

    /**
     * Public function to return grid display of services
     *
     * @since 1.0.0
     */
    public function shortcode_crm_service_masonry_grid_display($attributes)
    {
        if (isset($attributes["limit"]) && isset($attributes["limit"]) > 50) {
            $attributes["limit"] = 50;
        }

        $detailPage = $attributes['detail-page'];

        $clients = Fcrm_Service_Api::get_clients($attributes);
        $clients = isset($clients) ? $clients : [];
        $date_check = strtotime("now");
        $difference       = null;
        $difference_index = 0;

        $days = array();

        usort($clients, function($a, $b) {
            return strcmp($a->serviceDateTime, $b->serviceDateTime);
        });

        for ($i = 0; $i < count($clients); $i++) {
            $client = $clients[$i];
            $client->fullName = $this::formatName($client, $attributes["name-format"]);

            if (!empty($client->serviceDateTime)) {
                $d = strtotime($client->serviceDateTime);
                $diff = abs($d - $date_check);

                if ($difference == null || $diff < $difference) {
                    $difference = $diff;
                    $difference_index = $i;
                }

                $day = date("Y-m-d", $d);
                $days[$day][] = $client;
            }
        }

        ob_start();
        require_once (plugin_dir_path(dirname(__FILE__)) . 'public/partials/fcrm-service-public-masonry-grid-display.php');
        $content = ob_get_clean();
        return $content;
    }

    function getRelativeDate($date) {
        $today = new DateTime(); // This object represents current date/time
        $today->setTime( 0, 0, 0 ); // reset time part, to prevent partial comparison

        $match_date = new DateTime($date);
        $match_date->setTime( 0, 0, 0 ); // reset time part, to prevent partial comparison

        $diff = $today->diff( $match_date );
        $diffDays = (integer)$diff->format( "%R%a" ); // Extract days count in interval

        switch( $diffDays ) {
            case 0:
                return "Today at";
                break;
            case -1:
                return "Yesterday at";
                break;
            case +1:
                return "Tomorrow at";
                break;
            default:
                return null;
        }
    }

    function service_details_meta( $posts ) {
      $shortcode = 'show_crm_service_details';
      $callback_function = 'service_details_setmeta';

      return $this::service_details_to_wphead( $posts, $shortcode, $callback_function );
    }

    // To execute when shortcode is found
    function service_details_setmeta() {

      global $client;
      global $wp;
      $meta = '';
      $current_url = home_url(add_query_arg(array($_GET), $wp->request));

      $id = $wp->query_vars["id"];

      if (isset($id)) {
        $client = Fcrm_Service_Api::get_client($id);
        $fcrmDefaultImageUrl = get_option('fcrm_service_default_image');
        if ($client) {
          $clientName = $this::formatName($client, "display");
          $meta = $meta . '<meta property="og:url" content="'.$current_url.'">';
          $meta = $meta . '<meta property="og:type" content="article">';
          $meta = $meta . '<meta property="og:title" content="'.$clientName.'">';
          if ($client->hideDetails == true) {
            $meta = $meta . '<meta property="og:description" content="'.$client->meta_dod.'">';
          } else {
            $meta = $meta . '<meta property="og:description" content="'.$client->meta_service.'">';
          }

          if ($client->displayImage) {
            $meta = $meta . '<meta property="og:image" content="'.$client->displayImage.'">';
          } elseif ($fcrmDefaultImageUrl && strlen($fcrmDefaultImageUrl)) {
            $meta = $meta . '<meta property="og:image" content="'.$fcrmDefaultImageUrl.'">';
          }
        }
      }
      echo $meta;
    }

    // look for shortcode in the content and apply expected behaviour (don't edit!)
    function service_details_to_wphead( $posts, $shortcode, $callback_function ) {
      if ( empty( $posts ) )
        return $posts;

      $found = false;
      foreach ( $posts as $post ) {
        if ( stripos( $post->post_content, '[' . $shortcode ) !== false ) {
          $found = true;
          break;
        }
      }

      if ( $found ) {
        global $wpseo_front;
        if(defined($wpseo_front)){
          remove_action('wp_head',array($wpseo_front,'head'),1);
        } else if (class_exists('WPSEO_Frontend')) {
          $wp_thing = WPSEO_Frontend::get_instance();
          remove_action('wp_head',array($wp_thing,'head'),1);
        }
        add_action( 'wp_head', array($this, $callback_function) );
      }

      return $posts;
    }

    function plugin_query_vars( $qvars ) {
        $qvars[] = 'id';
        return $qvars;
    }
}
