<?php

/**
 * Provide a public-facing view for the plugin
 *
 * This file is used to markup the public-facing aspects of the plugin.
 *
 * @link       firehawkcrm.com
 * @since      1.0.0
 *
 * @package    Fcrm_Service
 * @subpackage Fcrm_Service/public/partials
 */
?>

<!-- This file should primarily consist of HTML with a little bit of PHP. -->
<?php
$fcrmDefaultImageUrl = get_option('fcrm_service_default_image');
$fcrmShowLocation = get_option('fcrm_service_show_location');
if (empty($fcrmShowLocation)) {
  $fcrmShowLocation = false;
} else if ($fcrmShowLocation == false || $fcrmShowLocation == '1') {
  $fcrmShowLocation = true;
} else {
  $fcrmShowLocation = false;
}
 ?>

<?php
if (function_exists('current_location') == false) {
  function current_location()
  {
      if (isset($_SERVER['HTTPS']) &&
          ($_SERVER['HTTPS'] == 'on' || $_SERVER['HTTPS'] == 1) ||
          isset($_SERVER['HTTP_X_FORWARDED_PROTO']) &&
          $_SERVER['HTTP_X_FORWARDED_PROTO'] == 'https') {
          $protocol = 'https://';
      } else {
          $protocol = 'http://';
      }
      return $protocol . $_SERVER['HTTP_HOST'];
  }
}
?>
<div class="firehawk-crm">
  <?php if (sizeof($clients) > 0): ?>
    <div class="glide">
      <div data-glide-el="track" class="glide__track">
        <ul class="glide__slides">
          <?php foreach ($clients as $client): ?>
          <li class="glide__slide">
              <div class="grid-item">
                <?php if (isset($client->displayImage)) : ?>
                  <div class="top-img" style="background-image: url(<?php echo $client->displayImage; ?>)"></div>
                <?php elseif ($fcrmDefaultImageUrl && strlen($fcrmDefaultImageUrl)) : ?>
                  <div class="top-img" style="background-image: url(<?php echo $fcrmDefaultImageUrl; ?>)"></div>
                <?php else: ?>
                  <div class="top-img" style="background: #f1f1f1;"></div>
                <?php endif; ?>
                <div class="content">
                  <div class="title">
                    <?php
                    echo $client->fullName;
                    ?>
                  </div>
                  <div class="dates">
                    <?php
                    if (isset($client->clientDateOfBirth) && isset($client->clientDateOfDeath)) {
                        $date1 = new DateTime($client->clientDateOfBirth);
                        $date2 = new DateTime($client->clientDateOfDeath);
                        echo $date1->format('Y') . " - " . $date2->format('Y');
                    } elseif (isset($client->clientDateOfDeath)) {
                        $date1 = new DateTime($client->clientDateOfDeath);
                        echo " - " . $date1->format('Y');
                    }
                    ?>
                  </div>

                  <?php
                    if ($client->hideDetails != true) {
                      $serviceTime = null;
                      if (isset($client->serviceDateTime)) {

                          $dateClass = $fcrmShowLocation == false ? ' space-under' : null;
                          echo '<div class="service-date' . $dateClass . '"><strong>';
                          $todayDate = new DateTime();
                          $serviceTime = new DateTime($client->serviceDateTime);
                          echo $serviceTime->format('D j F g:i a');
                          echo '</strong></div>';
                      }

                      if ($fcrmShowLocation == true) {
                        echo '<div class="venue">';
                        if (isset($client->serviceVenue) && isset($client->serviceVenue->googleLink)) {
                          echo '<a href="' . urldecode($client->serviceVenue->googleLink) . '" target="_blank" class="venue">';
                          if (isset($client->serviceVenue) && isset($client->serviceVenue->name)) {
                            echo $client->serviceVenue->name . "</br>";
                          }
                          if (isset($client->serviceVenue) && isset($client->serviceVenue->address)) {
                            echo $client->serviceVenue->address;
                          }
                          echo '</a>';
                        } else {
                          echo '<div class="venue">';
                          if (isset($client->serviceVenue) && isset($client->serviceVenue->name)) {
                            echo $client->serviceVenue->name . ",";
                          }
                          if (isset($client->serviceVenue) && isset($client->serviceVenue->address)) {
                            echo $client->serviceVenue->address;
                          }
                          echo '</div>';
                        }
                        echo '</div>';
                      }
                    }

                    if (isset($detailPage)) {
                      $shareUrl = current_location().'/'.$detailPage.'?id='.$client->id;
                    }
                    include(plugin_dir_path(__FILE__) . 'service-buttons.php');
                  ?>
                </div>
              </div>
          </li>
          <?php endforeach; ?>
        </ul>
      </div>
      <div class="glide__arrows" data-glide-el="controls">
        <button class="glide__arrow glide__arrow--left" data-glide-dir="<">prev</button>
        <button class="glide__arrow glide__jump--start" style="display: none">Jump to today</button>
        <button class="glide__arrow glide__arrow--right" data-glide-dir=">">next</button>
      </div>
    </div>
  <?php else: ?>
    <div class="empty-message">
      No upcoming services
    </div>
  <?php endif; ?>
</div>

<script>
  var startPoint = <?php echo isset($difference_index) ? $difference_index : 0; ?>;
  if (document.querySelector(".firehawk-crm .glide")) {
    var glide = new Glide('.glide', {
      type: 'slider',
      perView: 3,
      gap: 20,
      startAt: startPoint || 0,
      breakpoints: {
        800: {
          perView: 1
        },
        1140: {
          perView: 2
        }
      }
    })

    <?php $startPoint = isset($difference_index) ? $difference_index : 0; ?>;
    <?php if (sizeof($clients) > 3 && $startPoint > 3): ?>
      var jumpButton = document.querySelector(".firehawk-crm .glide .glide__jump--start")

      if (jumpButton) {
        jumpButton.addEventListener("click", function() {
          glide.go('=' + startPoint)
        })
      }
      glide.on(['mount.after', 'run'], function () {
        if (jumpButton) {
          if (startPoint > 0 && glide.index < startPoint-1) {
              jumpButton.style.display = null;
          } else {
              jumpButton.style.display = "none";
          }
        }
      })
    <?php endif; ?>

    glide.mount()
  }

  jQuery('.firehawk-crm .glide .service-buttons-group a.open-modal').click(function(event) {
    jQuery(this).modal({
      fadeDuration: 250
    });
    return false;
  });
</script>

<script>

jQuery('.firehawk-crm .glide .service-buttons-group a.social-share').each(function() {
  var tippyButton = this;
  var menu = jQuery(this).next(".social-menu")[0]
  var activeClipboard = null
  var tip = tippy(tippyButton, {
    content: menu,
    trigger: 'click',
    interactive: true,
    onShown(instance) {
      window.Sharer.init();
      var copyBtn = jQuery(menu).find(".copy-btn")[0];
      if (copyBtn) {
        activeClipboard = new ClipboardJS(copyBtn);
      }
    },
    onHide(instance) {
      if (activeClipboard) {
        activeClipboard.destroy()
        activeClipboard = null
      }
    }
  });

  jQuery(menu).children(".button").click(function() {
    if (tip) {
      setTimeout(function() {
        tip.hide();
      }, 200);
    }
  })
});
</script>


<?php
if (function_exists('service_buttons_check') == false) {
  include( plugin_dir_path( __FILE__ ) . 'service-buttons-functions.php');
}
?>
